summaryrefslogtreecommitdiffstats
path: root/include/drm/ttm/ttm_device.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/drm/ttm/ttm_device.h')
-rw-r--r--include/drm/ttm/ttm_device.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/drm/ttm/ttm_device.h b/include/drm/ttm/ttm_device.h
index c22f30535c84..39b8636b1845 100644
--- a/include/drm/ttm/ttm_device.h
+++ b/include/drm/ttm/ttm_device.h
@@ -252,9 +252,10 @@ struct ttm_device {
spinlock_t lru_lock;
/**
* @pinned: Buffer objects which are pinned and so not on any LRU list.
*/
- struct list_head pinned;
+ struct list_head unevictable;
/**
* @dev_mapping: A pointer to the struct address_space for invalidating
@@ -252,9 +252,10 @@ struct ttm_device {
spinlock_t lru_lock;
/**
- * @pinned: Buffer objects which are pinned and so not on any LRU list.
+ * @unevictable: Buffer objects which are pinned or swapped and as such
+ * not on an LRU list.
*/